@@ -17,17 +17,15 @@ package Dist::Zilla::Plugin::ModuleBuild::Custom;
 # ABSTRACT: Allow a dist to have a custom Build.PL
 #---------------------------------------------------------------------
 
-our $VERSION = '4.00';
-# This file is part of Dist-Zilla-Plugins-CJM 4.02 (November 3, 2011)
+our $VERSION = '4.03';
+# This file is part of Dist-Zilla-Plugins-CJM 4.03 (November 11, 2011)
 
 
 use Moose;
 use Moose::Autobox;
 extends 'Dist::Zilla::Plugin::ModuleBuild';
-with 'Dist::Zilla::Role::FilePruner';
-
-use Data::Dumper ();
-use Scalar::Util 'reftype';
+with qw(Dist::Zilla::Role::FilePruner
+        Dist::Zilla::Role::HashDumper);
 
 # We're trying to make the template executable before it's filled in,
 # so we want delimiters that look like comments:
@@ -59,7 +57,7 @@ sub prune_files {
   my ($self) = @_;
 
   my $files = $self->zilla->files;
-  @$files = grep { not($_->name eq 'META.yml' and
+  @$files = grep { not($_->name =~ /^META\.(?:yml|json)$/ and
                        $_->isa('Dist::Zilla::File::OnDisk')) } @$files;
 
   return;
@@ -71,48 +69,10 @@ sub get_meta
   my $self = shift;
 
   # Extract the wanted keys from distmeta:
-  return $self->_extract_keys(distmeta1 => $self->distmeta1, @_);
+  return $self->extract_keys(distmeta1 => $self->distmeta1, @_);
 } # end get_meta
 #---------------------------------------------------------------------
 
-sub _extract_keys
-{
-  my $self = shift;
-  my $type = shift;
-  my $hash = shift;
-
-  # Extract the wanted keys from the hash:
-  my %want;
-
-  foreach my $key (@_) {
-    $self->log_debug("Fetching $type key $key");
-    next unless defined $hash->{$key};
-
-    # Skip keys with empty value:
-    my $reftype = reftype($hash->{$key});
-    if (not $reftype) {}
-    elsif ($reftype eq 'HASH')  { next unless %{ $hash->{$key} } }
-    elsif ($reftype eq 'ARRAY') { next unless @{ $hash->{$key} } }
-
-    $want{$key} = $hash->{$key};
-  } # end foreach $key
-
-  # Format them for inclusion:
-  my $data = Data::Dumper->new([ \%want ])
-      ->Indent(1)->Sortkeys(1)->Terse(1)->Dump;
-
-  if ($data eq "{}\n") {
-    $data = '';
-  } else {
-    $data =~ s/^\{\n//     or die "Dump prefix! $data";
-    $data =~ s/\n\}\n\z/,/ or die "Dump postfix! $data";
-  }
-
-  return $data;
-} # end _extract_keys
-
-#---------------------------------------------------------------------
-
 
 sub get_prereqs
 {
@@ -135,7 +95,7 @@ sub get_default
 {
   my $self = shift;
 
-  return $self->_extract_keys(module_build => $self->_default_mb_args, @_);
+  return $self->extract_keys(module_build => $self->_default_mb_args, @_);
 } # end get_default
 
 #---------------------------------------------------------------------
@@ -195,9 +155,9 @@ Dist::Zilla::Plugin::ModuleBuild::Custom - Allow a dist to have a custom Build.P
 
 =head1 VERSION
 
-This document describes version 4.00 of
-Dist::Zilla::Plugin::ModuleBuild::Custom, released November 3, 2011
-as part of Dist-Zilla-Plugins-CJM version 4.02.
+This document describes version 4.03 of
+Dist::Zilla::Plugin::ModuleBuild::Custom, released November 11, 2011
+as part of Dist-Zilla-Plugins-CJM version 4.03.
 
 =head1 SYNOPSIS
 
@@ -239,6 +199,10 @@ C<##{> and C<##}>, because that makes them look like comments.
 That makes it easier to have a F<Build.PL> that works both before and
 after it is processed as a template.
 
+This is particularly useful for XS-based modules, because it can allow
+you to build and test the module without the overhead of S<C<dzil build>>
+after every small change.
+
 The template may use the following variables:
 
 =over
@@ -316,6 +280,18 @@ This is equivalent to
 In other words, it returns all the keys that describe the
 distribution's prerequisites.
 
+=head1 SEE ALSO
+
+The <MakeMaker::Custom|Dist::Zilla::Plugin::MakeMaker::Custom>
+plugin does basically the same thing as this plugin, but for
+F<Makefile.PL> (if you prefer L<ExtUtils::MakeMaker>).
+
+
+=for Pod::Coverage
+prune_files
+setup_installer
+template_error
+
 =head1 DEPENDENCIES
 
 ModuleBuild::Custom requires L<Dist::Zilla> (4 or later) and
@@ -328,12 +304,6 @@ will help catch errors in your templates.
 You must not use this in conjunction with the
 L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild> plugin.
 
-
-=for Pod::Coverage
-prune_files
-setup_installer
-template_error
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
